==> psi-plugins-debug-1.5-3-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/pepchangenotifyplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /build/psi-plugins/src/plugins-1.5/generic/pepchangenotifyplugin/pepchangenotify.png
  0x0,0x0,0x1,0xe8,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x1,0xaf,0x49,0x44,0x41,0x54,0x78,0x5e,0xa5,0x93,0x4d,0x4b,0x1b,0x61,
  0x14,0x85,0xcf,0x6b,0x7,0xfc,0xf8,0x7,0x85,0xe2,0xba,0x3b,0x37,0x69,0x16,0xdd,
  0xb9,0x13,0x2c,0x74,0xe7,0x47,0x5b,0xe2,0x26,0xda,0x94,0x81,0x52,0x30,0x50,0xba,
  0xd0,0x16,0x75,0xa9,0xdd,0x5,0x8a,0xae,0x74,0xa7,0x2b,0xc1,0x96,0xec,0xba,0x53,
  0x48,0x1a,0x68,0x4a,0x17,0xdd,0x95,0x4,0xa1,0xb,0xb3,0x33,0xc6,0xe4,0xfd,0xbc,
  0x72,0x5f,0xdf,0xc1,0xc0,0x28,0x52,0xf2,0xc0,0x81,0x19,0xee,0xcc,0x9c,0x73,0x66,
  0xee,0x8,0x22,0xc2,0x20,0xc,0x61,0x40,0xc4,0xe4,0xf3,0x5c,0xe6,0x4d,0xbe,0x50,
  0x2,0x90,0xe5,0x81,0xb5,0x6,0xc6,0x58,0x68,0xa3,0xa1,0xb5,0x86,0x52,0xca,0x4b,
  0x6a,0x5,0x25,0x25,0x24,0x4b,0xc9,0xea,0xcf,0x5f,0xf5,0xf8,0xfb,0xe1,0x6e,0xd,
  0x7,0x47,0x27,0x95,0xe6,0xe9,0x3f,0xfa,0x1f,0xea,0x7f,0x9a,0x94,0x7f,0xf7,0xa9,
  0xc2,0xf5,0x23,0x76,0x1e,0x7f,0xf4,0x10,0xfd,0x10,0x1,0x4,0x7,0x6d,0xc9,0x8b,
  0x20,0x30,0xe4,0x78,0x0,0x7f,0x3e,0xf1,0x78,0x9c,0x53,0xf8,0xc4,0x11,0xfa,0xd8,
  0x16,0x2,0x77,0xf1,0xea,0xd2,0x80,0x1c,0x12,0xa0,0xa4,0x2,0x13,0x71,0xe7,0x84,
  0x25,0x22,0x30,0x8e,0x0,0x65,0x1c,0x8c,0x73,0x6c,0xa,0x1,0x1,0x38,0x4e,0xe6,
  0x67,0x1e,0xa5,0xc2,0x3,0x8c,0xb1,0x21,0x36,0x61,0x75,0x6b,0xf,0xf7,0xf1,0x76,
  0xf1,0x5,0x18,0xa5,0x43,0x2,0x7e,0xdb,0xc,0xa7,0x5f,0x2f,0x2e,0x78,0x17,0x4b,
  0xe,0xca,0x10,0x5c,0x88,0x2c,0x40,0xb0,0xd6,0xf7,0x87,0xd,0x29,0xf9,0xb,0x31,
  0x11,0x1f,0x24,0xac,0x6c,0xee,0xe2,0x36,0xde,0xc7,0x2f,0xfd,0x8d,0x6,0x2e,0xa9,
  0x80,0xc4,0x38,0xe2,0x2e,0x49,0x85,0xb5,0x62,0xe,0xc6,0xf1,0x90,0x2f,0x24,0x88,
  0xc4,0xdf,0x2,0xce,0xb1,0x3b,0x80,0x90,0xca,0x18,0x3,0xcf,0xd6,0x97,0xfd,0xca,
  0xdf,0xc6,0x69,0x6a,0x1,0xce,0xbb,0x9a,0x2e,0x7a,0x9a,0x3a,0x5d,0x93,0x9a,0xd5,
  0x7e,0x37,0xe8,0xe9,0xd4,0xcc,0xf5,0x1e,0x7c,0x2d,0x7f,0x8b,0xdb,0xed,0x76,0x49,
  0x4a,0x99,0xd,0x5b,0xe6,0xb5,0xf3,0xf9,0x23,0x3a,0x3d,0x8b,0xb1,0x91,0x7,0x78,
  0x36,0x5f,0xe0,0xce,0x1c,0xdb,0x3b,0x5b,0x6b,0xab,0xc3,0xc3,0x23,0x71,0x12,0x3d,
  0x25,0x5e,0xef,0xd9,0xfc,0x32,0x31,0xd3,0x73,0xaf,0x89,0xcf,0xc3,0x2c,0x25,0xf1,
  0x61,0xa3,0x84,0x1b,0x67,0x5,0xd5,0xeb,0xf9,0xbd,0x3f,0x6b,0xb5,0x32,0x63,0xa3,
  0xa3,0x3f,0x2e,0xbb,0xdd,0x27,0x0,0xd5,0x82,0x33,0xfa,0x39,0x2e,0xef,0x63,0xe0,
  0xdf,0xf9,0xa,0x1b,0x23,0x94,0xac,0xd1,0x66,0x60,0x8b,0x0,0x0,0x0,0x0,0x49,
  0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // pepchangenotify.png
  0x0,0x13,
  0xd,0x6a,0x80,0xa7,
  0x0,0x70,
  0x0,0x65,0x0,0x70,0x0,0x63,0x0,0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,0x6e,0x0,0x6f,0x0,0x74,0x0,0x69,0x0,0x66,0x0,0x79,0x0,0x2e,0x0,0x70,
  0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,
  // :/icons/pepchangenotify.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x1,0xb2,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}

==> psi-plugins-debug-1.5-3.1-x86_64.pkg.tar.zst: usr/src/debug/psi-plugins/plugins-1.5/generic/pepchangenotifyplugin/.rcc/qrc_resources.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.15.14
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /startdir/src/plugins-1.5/generic/pepchangenotifyplugin/pepchangenotify.png
  0x0,0x0,0x1,0xe8,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x1,0xaf,0x49,0x44,0x41,0x54,0x78,0x5e,0xa5,0x93,0x4d,0x4b,0x1b,0x61,
  0x14,0x85,0xcf,0x6b,0x7,0xfc,0xf8,0x7,0x85,0xe2,0xba,0x3b,0x37,0x69,0x16,0xdd,
  0xb9,0x13,0x2c,0x74,0xe7,0x47,0x5b,0xe2,0x26,0xda,0x94,0x81,0x52,0x30,0x50,0xba,
  0xd0,0x16,0x75,0xa9,0xdd,0x5,0x8a,0xae,0x74,0xa7,0x2b,0xc1,0x96,0xec,0xba,0x53,
  0x48,0x1a,0x68,0x4a,0x17,0xdd,0x95,0x4,0xa1,0xb,0xb3,0x33,0xc6,0xe4,0xfd,0xbc,
  0x72,0x5f,0xdf,0xc1,0xc0,0x28,0x52,0xf2,0xc0,0x81,0x19,0xee,0xcc,0x9c,0x73,0x66,
  0xee,0x8,0x22,0xc2,0x20,0xc,0x61,0x40,0xc4,0xe4,0xf3,0x5c,0xe6,0x4d,0xbe,0x50,
  0x2,0x90,0xe5,0x81,0xb5,0x6,0xc6,0x58,0x68,0xa3,0xa1,0xb5,0x86,0x52,0xca,0x4b,
  0x6a,0x5,0x25,0x25,0x24,0x4b,0xc9,0xea,0xcf,0x5f,0xf5,0xf8,0xfb,0xe1,0x6e,0xd,
  0x7,0x47,0x27,0x95,0xe6,0xe9,0x3f,0xfa,0x1f,0xea,0x7f,0x9a,0x94,0x7f,0xf7,0xa9,
  0xc2,0xf5,0x23,0x76,0x1e,0x7f,0xf4,0x10,0xfd,0x10,0x1,0x4,0x7,0x6d,0xc9,0x8b,
  0x20,0x30,0xe4,0x78,0x0,0x7f,0x3e,0xf1,0x78,0x9c,0x53,0xf8,0xc4,0x11,0xfa,0xd8,
  0x16,0x2,0x77,0xf1,0xea,0xd2,0x80,0x1c,0x12,0xa0,0xa4,0x2,0x13,0x71,0xe7,0x84,
  0x25,0x22,0x30,0x8e,0x0,0x65,0x1c,0x8c,0x73,0x6c,0xa,0x1,0x1,0x38,0x4e,0xe6,
  0x67,0x1e,0xa5,0xc2,0x3,0x8c,0xb1,0x21,0x36,0x61,0x75,0x6b,0xf,0xf7,0xf1,0x76,
  0xf1,0x5,0x18,0xa5,0x43,0x2,0x7e,0xdb,0xc,0xa7,0x5f,0x2f,0x2e,0x78,0x17,0x4b,
  0xe,0xca,0x10,0x5c,0x88,0x2c,0x40,0xb0,0xd6,0xf7,0x87,0xd,0x29,0xf9,0xb,0x31,
  0x11,0x1f,0x24,0xac,0x6c,0xee,0xe2,0x36,0xde,0xc7,0x2f,0xfd,0x8d,0x6,0x2e,0xa9,
  0x80,0xc4,0x38,0xe2,0x2e,0x49,0x85,0xb5,0x62,0xe,0xc6,0xf1,0x90,0x2f,0x24,0x88,
  0xc4,0xdf,0x2,0xce,0xb1,0x3b,0x80,0x90,0xca,0x18,0x3,0xcf,0xd6,0x97,0xfd,0xca,
  0xdf,0xc6,0x69,0x6a,0x1,0xce,0xbb,0x9a,0x2e,0x7a,0x9a,0x3a,0x5d,0x93,0x9a,0xd5,
  0x7e,0x37,0xe8,0xe9,0xd4,0xcc,0xf5,0x1e,0x7c,0x2d,0x7f,0x8b,0xdb,0xed,0x76,0x49,
  0x4a,0x99,0xd,0x5b,0xe6,0xb5,0xf3,0xf9,0x23,0x3a,0x3d,0x8b,0xb1,0x91,0x7,0x78,
  0x36,0x5f,0xe0,0xce,0x1c,0xdb,0x3b,0x5b,0x6b,0xab,0xc3,0xc3,0x23,0x71,0x12,0x3d,
  0x25,0x5e,0xef,0xd9,0xfc,0x32,0x31,0xd3,0x73,0xaf,0x89,0xcf,0xc3,0x2c,0x25,0xf1,
  0x61,0xa3,0x84,0x1b,0x67,0x5,0xd5,0xeb,0xf9,0xbd,0x3f,0x6b,0xb5,0x32,0x63,0xa3,
  0xa3,0x3f,0x2e,0xbb,0xdd,0x27,0x0,0xd5,0x82,0x33,0xfa,0x39,0x2e,0xef,0x63,0xe0,
  0xdf,0xf9,0xa,0x1b,0x23,0x94,0xac,0xd1,0x66,0x60,0x8b,0x0,0x0,0x0,0x0,0x49,
  0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // icons
  0x0,0x5,
  0x0,0x6f,0xa6,0x53,
  0x0,0x69,
  0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // pepchangenotify.png
  0x0,0x13,
  0xd,0x6a,0x80,0xa7,
  0x0,0x70,
  0x0,0x65,0x0,0x70,0x0,0x63,0x0,0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,0x6e,0x0,0x6f,0x0,0x74,0x0,0x69,0x0,0x66,0x0,0x79,0x0,0x2e,0x0,0x70,
  0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,
  // :/icons
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,
  // :/icons/pepchangenotify.png
  0x0,0x0,0x0,0x10,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x90,0xad,0x19,0x36,0x8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_resources)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_resources)(); }
   } dummy;
}
